@@ -13,11 +13,7 @@ from cattrs import Converter
 from cattrs.gen import make_dict_structure_fn, override
 from lsprotocol.types import MarkupKind
 
-# pylint: disable=missing-class-docstring
-# pylint: disable=too-few-public-methods
-
 if sys.version_info >= (3, 10):
-    # pylint: disable-next=unexpected-keyword-arg
     light_dataclass = dataclass(kw_only=True, eq=False, match_args=False)
 else:
     light_dataclass = dataclass(eq=False)
@@ -145,10 +141,10 @@ def structure(cls: type) -> Any:
     return make_dict_structure_fn(
         cls,
         initialization_options_converter,
-        **{
+        **{  # type: ignore[arg-type]
             a.name: override(rename=convert_class_keys(a.name))
             for a in fields(cls)
-        }
+        },
     )
 
 
