@@ -23,7 +23,7 @@ from lsprotocol.types import (
     TextDocumentEdit,
     TextEdit,
 )
-from pygls.workspace import Document, Workspace
+from pygls.workspace import TextDocument, Workspace
 
 
 def is_valid_python(code: str) -> bool:
@@ -74,7 +74,7 @@ class RefactoringConverter:
         changed_files = self.refactoring.get_changed_files()
         for path, changed_file in changed_files.items():
             uri = path.as_uri()
-            document = self.workspace.get_document(uri)
+            document = self.workspace.get_text_document(uri)
             version = 0 if document.version is None else document.version
             text_edits = lsp_text_edits(document, changed_file)
             if text_edits:
@@ -91,7 +91,7 @@ _OPCODES_CHANGE = {"replace", "delete", "insert"}
 
 
 def lsp_text_edits(
-    document: Document, changed_file: ChangedFile
+    document: TextDocument, changed_file: ChangedFile
 ) -> List[Union[TextEdit, AnnotatedTextEdit]]:
     """Take a jedi `ChangedFile` and convert to list of text edits.
 
@@ -141,15 +141,13 @@ class Opcode(NamedTuple):
 
 
 def get_opcodes(old: str, new: str) -> List[Opcode]:
-    """Obtain typed opcodes from two files (old and new)"""
+    """Obtain typed opcodes from two files (old and new)."""
     diff = difflib.SequenceMatcher(a=old, b=new)
     return [Opcode(*opcode) for opcode in diff.get_opcodes()]
 
 
-# pylint: disable=too-few-public-methods
 class PositionLookup:
-    """Data structure to convert a byte offset in a file to a line number and
-    character."""
+    """Data structure to convert byte offset file to line number and character."""
 
     def __init__(self, code: str) -> None:
         # Create a list saying at what offset in the file each line starts.
@@ -160,8 +158,7 @@ class PositionLookup:
             offset += len(line)
 
     def get(self, offset: int) -> Position:
-        """Get the position in the file that corresponds to the given
-        offset."""
+        """Get the position in the file that corresponds to the given offset."""
         line = bisect_right(self.line_starts, offset) - 1
         character = offset - self.line_starts[line]
         return Position(line=line, character=character)
